//####
//# Legal Notice :
//#    Copyright, Harman International, 2015
//#    Private, proprietary information, the sole property of Harman.  The
//#    contents, ideas, and concepts expressed herein are not to be disclosed
//#    except within the confines of a confidential relationship and only
//#    then on a need to know basis.
//#
//#    Any entity in possession of this Harman Software shall not, and shall not
//#    permit any other person to, disclose, display, loan, publish, transfer
//#    (whether by sale, assignment, exchange, gift, operation of law or
//#    otherwise), license, sublicense, copy, or otherwise disseminate this
//#    Harman Software.
//#
//#    This Harman Software is owned by Harman and is protected by United States
//#    copyright laws, patent laws, international treaty provisions, and/or
//#    state of Texas trade secret laws.
//#
//#    Portions of this Harman Software may, from time to time, include
//#    pre-release code and such code may not be at the level of performance,
//#    compatibility and functionality of the final code. The pre-release code
//#    may not operate correctly and may be substantially modified prior to
//#    final release or certain features may not be generally released. Harman is
//#    not obligated to make or support any pre-release code. All pre-release
//#    code is provided "as is" with no warranties.
//#
//#    This Harman Software is provided with restricted rights. Use, duplication,
//#    or disclosure by the Government is subject to restrictions as set forth
//#    in subparagraph (1)(ii) of The Rights in Technical Data and Computer
//#    Software clause at DFARS 252.227-7013 or subparagraphs (1) and (2) of
//#    the Commercial Computer Software Restricted Rights at 48 CFR 52.227-19,
//#    as applicable.
//####


PROGRAM_NAME='MASTER'

DEFINE_DEVICE 
dvTP = 11112:1:0

DEFINE_CONSTANT
//dropTargets
INTEGER leftDT 	 = 16
INTEGER centerDT = 17
INTEGER rightDT  = 18
//draggables
INTEGER btnDG1	= 1
INTEGER btnDG2	= 2
INTEGER btnDG3	= 3
INTEGER btnDG4	= 4
INTEGER btnDG5	= 5

DEFINE_VARIABLE
//an array to store our dropTarget buttons
INTEGER dTBTNS[] = {leftDT ,centerDT ,rightDT}
//an array to store our draggable buttons
INTEGER dgBTNS[] = {btnDG1 ,btnDG2 ,btnDG3 ,btnDG4,btnDG5}
//an array to store draggable buttons belonging to group_1
INTEGER dgG1[] = {btnDG1,btnDG2}
//an array to store draggable buttons belonging to group_2
INTEGER dgG2[] = {btnDG3}
//an array to store draggable buttons belonging to group_3
INTEGER dgG3[] = {btnDG4,btnDG5}
//to track small/large Icon
INTEGER nLargeIcon = 0
//to store draggable address from start event
INTEGER nDragAddress = 0
//to store which group we are in 
INTEGER ngroupID = 0

DEFINE_MUTUALLY_EXCLUSIVE
([dvTP,1]..[dvTP,5])

//In this example the groups are defined as follows
//	- buttonAddresses 1,2  are assigned: group_1
//	- buttonAddress   3    are assigned: group_2
//	- buttonAddresses 4,5  are assigned: group_3
// 	- leftDT   [16] will accept draggables from: group_1
// 	- centerDT [17] will accept draggables from: group_1, group_2, group_3
// 	- rightDT  [18] will accept draggables from: group_3

DEFINE_EVENT

DATA_EVENT[dvTP]
{
    ONLINE:
    {
	nLargeIcon = 0
	
	//By default ^BDC is enabled, let's disable it
	SEND_STRING dvTP,"'BDC-0,0,0,0,0,0,0'"
	
	//Let's make sure we are starting in state 1
	SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',1,1,0'"
	SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',1,1,0'"
	SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',1,1,0'"
    }
}


//Custom event for START [1]
//Any time a draggable is initiated (long press, dragShadow appears)
//a START event is sent.
//CUSTOM_EVENT[dvTP,ID,Type]
CUSTOM_EVENT[dvTP,dgBTNS,1]
{
    //to store the draggable group name
    CHAR cDragGroup[DATA_MAX_VALUE_LENGTH]
    
    //Get the dragButtonAddress from the customEvent
    nDragAddress = custom.value1
    cDragGroup = custom.text
    
    if(COMPARE_STRING(cDragGroup,'group_1'))
    {
	ngroupID = 1
	if(nLargeIcon)
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',4,4,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',4,4,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',5,5,0'"
	}
	else
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',2,2,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',2,2,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',3,3,0'"
	}
    }
    else if(COMPARE_STRING(cDragGroup,'group_2'))
    {
	ngroupID = 2
	if(nLargeIcon)
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',5,5,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',4,4,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',5,5,0'"
	}
	else
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',3,3,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',2,2,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',3,3,0'"
	}
    }
    else
    {
	ngroupID = 3
	if(nLargeIcon)
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',5,5,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',4,4,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',4,4,0'"
	}
	else
	{
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',3,3,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',2,2,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',2,2,0'"
	}
    }
}

//Since we are signaling what groups are valid on the START event,
//there is no need to handle ENTER or EXIT events.


//Custom event for DROP [4]
//A DROP event occurs when a draggable has been released within the boundaries
//of a valid dropTarget.  A valid dropTarget is a dropTarget that has a group
//which the draggable is assigned to.
CUSTOM_EVENT[dvTP,dTBTNS,4]
{
    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',1,1,0'"
    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',1,1,0'"
    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',1,1,0'" 
    //turn on the source(draggable)
    ON[dvTP,nDragAddress]
}
//Custom event for CANCEL [5]
//A CANCEL event occurs when a draggable has been released over anything that
//is not a VALID dropTarget.
CUSTOM_EVENT[dvTP,dgBTNS,5]
{
    	    SEND_COMMAND dvTP,"'^ANI-',ITOA(leftDT),',1,1,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(centerDT),',1,1,0'"
	    SEND_COMMAND dvTP,"'^ANI-',ITOA(rightDT),',1,1,0'"   
}

BUTTON_EVENT[dvTP,8] //CLEAR DISPLAY SOURCES
{
  PUSH:
  {
    OFF[dvTP,1]
    OFF[dvTP,2]
    OFF[dvTP,3]
    OFF[dvTP,4]
    OFF[dvTP,5]
  }
}

BUTTON_EVENT[dvTP,9] //SMALL/LARGE ICON DEMO MODE
{
  PUSH:
  {
    [dvTP,9] = ![dvTP,9]
    nLargeIcon = [dvTP,9]
  }
} 